<?php
require_once "modelo/Banco.php";
class Cargo implements JsonSerializable
{
    private $idCargo;
    private $nomeCargo;
    private $banco;

    public function jsonSerialize(){
        $json = array();
        $json['idCargo'] = $this->getIdCargo();
        $json['nomeCargo'] = $this->getNomeCargo();
        return $json;
    }
    public function create(){
        //instancia do banco.
        $this->banco = new Banco();
        //prepara a instrução de insert no banco
        $stmt = $this->banco->getConexao()->prepare("INSERT INTO Cargo (nomeCargo) VALUES (?);");
        //substitui os "s" pelos interrogações e valore de variáveis.
        $stmt->bind_param("s", $this->nomeCargo);
        //execura a instrução no banco de dados.
        $resposta = $stmt->execute();
        //retorna o id do registro que foi inserido no banco.
        $idCadastrado = $this->banco->getConexao()->insert_id;
        //passa para a instancia da classe o id que foi cadastrado
        $this->setIdCargo($idCadastrado);
        return $resposta;
    }
    public function cargoExiste(){
        $this->banco = new Banco();  //faz uma instância de banco  
        //cria um hash utilizando o algoritmo md5 para a senha
        //prepara a instrução de select no banco
        $sql = "select count(*) as qtd from cargo where nomeCargo = ?";
        $stmt = $this->banco->getConexao()->prepare($sql);
        //víncula os parametros substituindo os "?" pelos valores correspondentes.
        $stmt->bind_param("s", $this->nomeCargo);
        $stmt->execute();  //executa a  instrução sql no sgbd
        //recupera os dados referentes a execução do sql
        $resultado = $stmt->get_result();
        //estrutura de repetição que passa por todos os dados
        while ($linha = $resultado->fetch_object()) {
            //verifica se qtd é igual a 1.
            //igual a 1 significa que existe 1 usuario
            //com o email e senha fornecido. 
            if ($linha->qtd == 1) {
                return true;
            }
        }
        return false;
    }

    public function read($idCargo=null)
    {
        $this->banco = new Banco(); //Instancia a classe banco
        //prepara a instrução de select no banco
        if($idCargo!=null){
            $stmt = $this->banco->getConexao()->prepare("select *  from cargo where idCargo= ? order by nomeCargo;");
            //substitui os "i" pelo interrogação e valor da variável.
            $stmt->bind_param("i", $idCargo);
        }else{
       
            $stmt = $this->banco->getConexao()->prepare("select *  from cargo order by nomeCargo;");
        }
        $stmt->execute(); //executa a instrução no sgbd
        $resultado = $stmt->get_result(); //recupera os dados referentes a execução da instrução.
     
        //cria um vetor de objetos com os do usuário do id.
        $cargos= array();
        $i=0;
        while ($linha = $resultado->fetch_object()) {
            $cargos[$i] = new Cargo();
            $cargos[$i]->setIdCargo($linha->idCargo);
            $cargos[$i]->setNomeCargo($linha->nomeCargo);
            $i++;
        }
        
        return   $cargos; //retorna um vetor com os dados do usuário.
    }
    public function update(){
        $this->banco = new Banco(); //Instancia a classe banco   
      
        //prepara a instrução de update no banco
        $stmt = $this->banco->getConexao()->prepare("update cargo 
                                    set nomeCargo=?
                                    where idCargo = ?");
        //substitui os "s,i" pelos interrogações e valores de variáveis.
        $stmt->bind_param("si", $this->nomeCargo, $this->idCargo);
        return $stmt->execute();  //executa a instrução no sgbd
    }

    public function delete()
    {
        $this->banco = new Banco();  //Instancia a classe banco
        //prepara a instrução de delete no banco
        $stmt = $this->banco->getConexao()->prepare("delete from cargo where idCargo = ?");
        //substitui o ? pelo "i"(inteiro) que corresponde ao idUsuario
        $stmt->bind_param("i", $this->idCargo);
        //retorna verdadeiro se a instrução foi executa com sucesso no sgbd
        return $stmt->execute(); //executa a instrução no sgbd
    }
    /**
     * Get the value of idCargo
     */
    public function getIdCargo()
    {
        return $this->idCargo;
    }

    /**
     * Set the value of idCargo
     *
     * @return  self
     */
    public function setIdCargo($idCargo)
    {
        $this->idCargo = $idCargo;

        return $this;
    }

    /**
     * Set the value of nomeCargo
     *
     * @return  self
     */
    public function setNomeCargo($nomeCargo)
    {
        $this->nomeCargo = $nomeCargo;

        return $this;
    }

    /**
     * Get the value of nomeCargo
     */
    public function getNomeCargo()
    {
        return $this->nomeCargo;
    }
}
