<?php
require_once "modelo/Banco.php";
require_once "modelo/Cargo.php";

class Funcionario implements JsonSerializable
{
    private $idFuncionario;
    private $nome;
    private $email;
    private $senha;
    private $recebeValeTransporte;
    private $cargo;
    private $banco;
    public function jsonSerialize()
    {
        $json = array();
        $json['idFuncionario'] = $this->getIdFuncionario();
        $json['nome'] = $this->getNome();
        $json['email'] = $this->getEmail();
        $json['recebeValeTransporte'] = $this->getRecebeValeTransporte();
        $json['cargo'] = $this->getCargo();      
        return $json;
    }

    public function verificarUsuarioSenha(){
        $this->banco = new Banco(); //faz uma instância de banco   
        $this->senha = md5($this->senha); //cria um hash utilizando o algoritmo md5 para a senha
        $sql = "select count(*) as qtd ,nome,idFuncionario  from funcionario where email = ? and senha =?";
        $stmt = $this->banco->getConexao()->prepare($sql);
        $stmt->bind_param("ss", $this->email, $this->senha);
        $stmt->execute();  //executa a  instrução sql no sgbd
        $resultado = $stmt->get_result();   //recupera os dados referentes a execução do sql
        //estrutura de repetição que passa por todos os dados
        while ($linha = $resultado->fetch_object()) { 
            //verifica se qtd é igual a 1, significa que existe 1 usuario om o email e senha fornecido.
            if ($linha->qtd == 1) {
                $this->setIdFuncionario($linha->idFuncionario);
                $this->setNome($linha->nome);
                return true;
            }
        }
        return false;
    }
    public function create()
    {
        //instancia do banco.
        $this->banco = new Banco();
        $senha = md5($this->senha);
        //prepara a instrução de insert no banco
        $stmt = $this->banco->getConexao()->prepare("INSERT INTO funcionario (nome, email,senha, recebeValeTransporte, Cargo_idCargo) VALUES (?, ?, ?, ?, ?);");
        $idCargo = $this->cargo->getIdCargo();
        //substitui os "s" pelos interrogações e valore de variáveis.
        $stmt->bind_param("sssii", $this->nome,$this->email, $senha,$this->recebeValeTransporte,$idCargo);
        
        //execura a instrução no banco de dados.
        $resposta = $stmt->execute();
        //retorna o id do registro que foi inserido no banco.
        $idCadastrado = $this->banco->getConexao()->insert_id;
        //passa para a instancia da classe o id que foi cadastrado
        $this->setIdFuncionario($idCadastrado);
        return $resposta;
    }


    public function funcionarioExiste(){
        $this->banco = new Banco();  //faz uma instância de banco  
        //cria um hash utilizando o algoritmo md5 para a senha
        //prepara a instrução de select no banco
        $sql = "select count(*) as qtd from funcionario where email = ?";
        $stmt = $this->banco->getConexao()->prepare($sql);
        //víncula os parametros substituindo os "?" pelos valores correspondentes.
        $stmt->bind_param("s", $this->email);
        $stmt->execute();  //executa a  instrução sql no sgbd
        //recupera os dados referentes a execução do sql
        $resultado = $stmt->get_result();
        //estrutura de repetição que passa por todos os dados
        while ($linha = $resultado->fetch_object()) {
            //verifica se qtd é igual a 1.
            //igual a 1 significa que existe 1 usuario
            //com o email e senha fornecido. 
            if ($linha->qtd == 1) {
                return true;
            }
        }
        return false;
    }

    public function read($idCargo=null)
    {
        $this->banco = new Banco(); //Instancia a classe banco
        //prepara a instrução de select no banco
        if($idCargo!=null){
            $stmt = $this->banco->getConexao()->prepare("select *  from funcionario where idFuncionario= ? order by nome;");
            //substitui os "i" pelo interrogação e valor da variável.
            $stmt->bind_param("i", $idCargo);
        }else{
         
            $stmt = $this->banco->getConexao()->prepare("select *  from funcionario join cargo on idcargo=cargo_idcargo order by nome;");
        }
        $stmt->execute(); //executa a instrução no sgbd
        $resultado = $stmt->get_result(); //recupera os dados referentes a execução da instrução.
     
        //cria um vetor de objetos com os do usuário do id.
        $funcionarios= array();
        $i=0;
        while ($linha = $resultado->fetch_object()) {
            $funcionarios[$i] = new Funcionario();
            $funcionarios[$i]->setIdFuncionario($linha->idFuncionario);
            $funcionarios[$i]->setNome($linha->nome);
            $funcionarios[$i]->setEmail($linha->email);
            $funcionarios[$i]->setRecebeValeTransporte($linha->recebeValeTransporte);
            $cargo = new Cargo();
            $cargo->setIdCargo($linha->idCargo);
            $cargo->setNomeCargo($linha->nomeCargo);
            $funcionarios[$i]->setCargo( $cargo );
            $i++;
        }
        return   $funcionarios; //retorna um vetor com os dados do usuário.
    }
    public function update(){
        $this->banco = new Banco(); //Instancia a classe banco   
        $senha = md5($this->senha);
        //prepara a instrução de update no banco
        $stmt = $this->banco->getConexao()->prepare("update funcionario 
                                    set nome=?,
                                        email=?,
                                        senha=?,
                                        recebeValeTransporte=?,
                                        Cargo_idCargo =?
                                    where idFuncionario = ?");
        //substitui os "s,i" pelos interrogações e valores de variáveis.
        $idCargo = $this->getCargo()->getidcargo();

      
        $stmt->bind_param("sssiii", $this->nome, $this->email, $senha,$this->recebeValeTransporte, $idCargo,$this->idFuncionario);
        return $stmt->execute();  //executa a instrução no sgbd
    }

    public function delete()
    {
        $this->banco = new Banco();  //Instancia a classe banco
        //prepara a instrução de delete no banco
        $stmt = $this->banco->getConexao()->prepare("delete from funcionario where idFuncionario = ?");
        //substitui o ? pelo "i"(inteiro) que corresponde ao idUsuario
        $stmt->bind_param("i", $this->idFuncionario);
        //retorna verdadeiro se a instrução foi executa com sucesso no sgbd
        return $stmt->execute(); //executa a instrução no sgbd
    }

    /**
     * Get the value of idFuncionario
     */ 
    public function getIdFuncionario()
    {
        return $this->idFuncionario;
    }

    /**
     * Set the value of idFuncionario
     *
     * @return  self
     */ 
    public function setIdFuncionario($idFuncionario)
    {
        $this->idFuncionario = $idFuncionario;

        return $this;
    }

    /**
     * Get the value of nome
     */ 
    public function getNome()
    {
        return $this->nome;
    }

    /**
     * Set the value of nome
     *
     * @return  self
     */ 
    public function setNome($nome)
    {
        $this->nome = $nome;

        return $this;
    }

    /**
     * Get the value of email
     */ 
    public function getEmail()
    {
        return $this->email;
    }

    /**
     * Set the value of email
     *
     * @return  self
     */ 
    public function setEmail($email)
    {
        $this->email = $email;

        return $this;
    }

    /**
     * Get the value of senha
     */ 
    public function getSenha()
    {
        return $this->senha;
    }

    /**
     * Set the value of senha
     *
     * @return  self
     */ 
    public function setSenha($senha)
    {
        $this->senha = $senha;

        return $this;
    }

    /**
     * Get the value of recebeValeTransporte
     */ 
    public function getRecebeValeTransporte()
    {
        return $this->recebeValeTransporte;
    }

    /**
     * Set the value of recebeValeTransporte
     *
     * @return  self
     */ 
    public function setRecebeValeTransporte($recebeValeTransporte)
    {
        $this->recebeValeTransporte = $recebeValeTransporte;

        return $this;
    }

    /**
     * Get the value of banco
     */ 
    public function getBanco()
    {
        return $this->banco;
    }

    /**
     * Set the value of banco
     *
     * @return  self
     */ 
    public function setBanco($banco)
    {
        $this->banco = $banco;

        return $this;
    }

    /**
     * Get the value of cargo
     */ 
    public function getCargo()
    {
        return $this->cargo;
    }

    /**
     * Set the value of cargo
     *
     * @return  self
     */ 
    public function setCargo($cargo)
    {
        $this->cargo = $cargo;

        return $this;
    }
}